==> org.At.tair.db_2.9.0.tar.gz: org.At.tair.db/man/org.At.tairCHRLOC.Rd <==
\name{org.At.tairCHRLOC}
\alias{org.At.tairCHRLOC}
\alias{org.At.tairCHRLOCEND}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  org.At.tairCHRLOC is an R object that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.

  The CHRLOCEND mapping is the same as the CHRLOC mapping except that it
  specifies the ending base of a gene instead of the start.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the object was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Mappings were based on data provided by: Tair  
  ftp://ftp.arabidopsis.org/Maps/seqviewer\_data/sv\_gene.data  
  With a date stamp from the source of: 2013-Mar05
  
}
\examples{
        x <- org.At.tairCHRLOC
        # Get the tair identifiers that are mapped to chromosome locations
        mapped_tairs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_tairs])
        if(length(xx) > 0) {
          # Get the CHRLOC for the first five tairs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}

==> org.At.tair.db_2.10.1.tar.gz: org.At.tair.db/man/org.At.tairCHRLOC.Rd <==
\name{org.At.tairCHRLOC}
\alias{org.At.tairCHRLOC}
\alias{org.At.tairCHRLOCEND}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  org.At.tairCHRLOC is an R object that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.

  The CHRLOCEND mapping is the same as the CHRLOC mapping except that it
  specifies the ending base of a gene instead of the start.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the object was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Mappings were based on data provided by: Tair  
  ftp://ftp.arabidopsis.org/Maps/seqviewer\_data/sv\_gene.data  
  With a date stamp from the source of: 2013-May16
  
}
\examples{
        x <- org.At.tairCHRLOC
        # Get the tair identifiers that are mapped to chromosome locations
        mapped_tairs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_tairs])
        if(length(xx) > 0) {
          # Get the CHRLOC for the first five tairs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}
